@@ -18,7 +18,7 @@ from __future__ import absolute_import
 import io
 import os
 import time
-import typing  # noqa
+import typing
 from multiprocessing import Process as MultiProcess
 
 import psutil
@@ -583,3 +583,61 @@ def check_or_start_background_process(bg_function=None,
                              bg_process_name=bg_process_name, **kwargs)
     # check test is not failing from the start
     check_function()
+
+
+def check_or_start_external_process(start_function,
+                                    check_function,
+                                    liveness_function,
+                                    stop_function=None,
+                                    **kwargs):
+    """Start or restart an external process.
+
+    Check if a process exists, if so restart the process, execute some check
+    logic i.e. a check function. if the process by name isn't running, start a
+    new separate process i.e an iperf3 client
+
+    :param start_function: function name
+    :param check_function: function name
+    :param liveness_function: function name
+    :param stop_function: function name
+    """
+    try:
+        if liveness_function(**kwargs):
+            # if we want to terminate the specific external process by
+            # close it, otherwise the check will continue to run in the
+            # background
+            # This step is needed e.g. for iperf as it stores results
+            # in the file when it is stopped
+            if stop_function:
+                stop_function(**kwargs)
+                LOG.info('checked and stopped previous external processes and '
+                         'log starting a new external process')
+                # wait before running check_function, it may take a couple of
+                # seconds to write the log file
+                time.sleep(3)
+
+            # check logs of the process
+            # execute process check i.e. go over process results file and
+            # truncate the log file
+            LOG.info(f'running a check function: {check_function} '
+                     f'for the external process.')
+            check_function(**kwargs)
+
+        else:
+            # First time the test is run:
+            # if background process by specific name is not present ,
+            # start one in the background:
+            LOG.info('No previous external processes found')
+    finally:
+        # restart the process
+        LOG.info(
+            f'Starting a new external process of function: {start_function}')
+        start_function(**kwargs)
+        # wait before running liveness_function, it may take a couple of
+        # seconds to start the process - the command was sent in background,
+        # not waiting until it started running
+        time.sleep(3)
+        if not liveness_function(**kwargs):
+            tobiko.fail(f'Service did not start properly with '
+                        f'function: {start_function} '
+                        f'and arguments: {kwargs}')
